import { Component, OnInit } from '@angular/core';
import { AngularFirestore } from '@angular/fire/firestore';
import * as firebase from 'firebase';
import { FormGroup, FormBuilder, Validators } from '@angular/forms';
import { UsersService } from 'src/app/services/users.service';
// Model
import { User } from 'src/app/models/user';
import { take } from 'rxjs/operators';



@Component({
  selector: 'app-add-user',
  templateUrl: './add-user.component.html',
  styleUrls: ['./add-user.component.css']
})
export class AddUserComponent implements OnInit {

  addUserForm : FormGroup

  // USER FEEDBACK MESSAGES
  formSuccessMsg: boolean = false // formulaire rempli ou pas
  duplicateEmail: any[]; // email deja existant ou pas
  emailExistErrorMsg: string = null;
  duplicateEmailObs$: any

  // users$: any[]; 

  user : User = {
    id: '',
    name: '',
    surname: '',
    birthDate: '',
    arrivalDate: '',
    position: '',
    interests: '',
    description: '',
    email: '',
    password: '',
    // avatar standard pour nouveau user
    photo: 'https://firebasestorage.googleapis.com/v0/b/coffee-app-76b18.appspot.com/o/images%2Favatar.png?alt=media&token=ad2e1785-127c-4158-a4c6-1c54396b16dd',
    companies: '',
    role: '',
    profileComplete: false,
    mood: '',
    protectedByUser: '',
    userToProtect: '',
    incognito: true,
    sex: '',
    group: '',

  }


  companies = ['Thales', 'Amadeus', 'Castorama', 'Fnac', 'Mansbridge']
  sex = ['Femme', 'Homme']
  group = ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10']
  
  constructor(private formBuilder: FormBuilder, private afs: AngularFirestore, private usersService: UsersService) { }

  ngOnInit() {

 
    this.companies.sort() // on trie les entreprises par ordre alphabetique

    // this.usersService.getUsers().subscribe(results =>
    //   {
    //     this.users$ = results // Converting observable into array

    //   }
    // )

    // Initialisation formulaire
    this.addUserForm = this.formBuilder.group({
      name: ['', Validators.required], // A renseigner dans formcontrolname=""
      surname: ['', Validators.required], 
      companies: ['', Validators.required],
      email: ['', Validators.email],
      sex: ['', Validators.required],
      group: ['', Validators.required],
     
    })

  }


  submitForm(){
    //console.log (this.addUserForm.value)
    
    this.user.name = this.addUserForm.get('name').value;
    this.user.surname = this.addUserForm.get('surname').value;
    this.user.companies = this.addUserForm.get('companies').value;
    this.user.email = this.addUserForm.get('email').value;
    this.user.sex = this.addUserForm.get('sex').value;
    this.user.group = this.addUserForm.get('group').value;
    this.user.mood = 10;
    this.user.role = 'user';
    this.user.unreadMessagesFromAngel = 0;
    this.user.unreadMessagesFromProtege = 0;
    this.user.password = '123456';
    
    this.duplicateEmailObs$ = this.usersService.checkDuplicateEmail(this.user.email)
    console.log('this.duplicateEmailObs$', this.duplicateEmailObs$)


    this.duplicateEmailObs$.subscribe(results =>
      {
        this.duplicateEmail = results // Converting observable into array
        console.log('this.duplicateEmail', this.duplicateEmail.length)
          if(this.duplicateEmail && !this.duplicateEmail.length)  // est ce que l'array est vide ? Alors il n'y a pas d'emails en doublon
            {
              this.afs
              .collection("users")
              .add(this.user) 
              this.formSuccessMsg = true
              firebase.auth().createUserWithEmailAndPassword(this.user.email, this.user.password)
              
              
            }
        
      }
    )


    //  On réinitialise les champs du formulaire
    this.addUserForm = this.formBuilder.group({
      name: '', 
      surname: '', 
      companies: '',
      email: '',
      sex: '',
      group: '',
     
    })
   
  } 

 

}
