import { BrowserModule } from '@angular/platform-browser';
import { NgModule } from '@angular/core';
import { PickerModule } from '@ctrl/ngx-emoji-mart'
import { EmojiModule } from '@ctrl/ngx-emoji-mart/ngx-emoji';

//CONFIGURATION FIREBASE
import { AngularFireModule } from "@angular/fire";
import { AngularFirestoreModule } from "@angular/fire/firestore";
import { AngularFireStorageModule } from "@angular/fire/storage";
import { environment } from '../environments/environment';

// SERVICES
import { ItemService } from './services/item.service';
import { UsersService } from './services/users.service';
import { ChatService } from './services/chat.service';

// IMPORT DES COMPOSANTS MATERIAL
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { MaterialModule } from './material/material.module';

import { AppRoutingModule } from './app-routing.module';
import { AppComponent } from './app.component';

import { NavigationComponent } from './components/navigation/navigation.component';
import { ItemsComponent } from './components/items/items.component';
import { SliderComponent } from './components/slider/slider.component';
import { AddItemComponent } from './components/add-item/add-item.component';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { EditItemComponent } from './components/edit-item/edit-item.component';
import { FirebaseTestsComponent } from './components/firebase-tests/firebase-tests.component';
import { StyleDirective } from './style.directive';

import { RegisterComponent } from './components/register/register.component';
import { DashboardComponent } from './admin/dashboard/dashboard.component';
import { EditUserComponent } from './components/users/edit-user/edit-user.component';
import { AddItemTestComponent } from './components/add-item-test/add-item-test.component';
import { ReactiveFormComponent } from './components/reactive-form/reactive-form.component';
import { FirebaseOperationsComponent } from './helpers/firebase-operations/firebase-operations.component';
import { AddUserComponent } from './admin/dashboard/components/add-user/add-user.component';
import { ListUserComponent } from './admin/dashboard/components/list-user/list-user.component';
import { SigninAdminComponent } from './components/signin-admin/signin-admin.component';
import { SigninUserComponent } from './user/dashboard/signin-user/signin-user.component';
import { UserDashboardComponent } from './user/dashboard/user-dashboard/user-dashboard.component';
import { RegisterUserComponent } from './user/dashboard/register-user/register-user.component';

import { ImageCropperModule } from 'ngx-image-cropper';
import { ResetPasswordComponent } from './user/dashboard/reset-password/reset-password.component';
import { PanelHolderComponent } from './user/dashboard/panels/panel-holder/panel-holder.component';
import { PanelAngelComponent } from './user/dashboard/panels/panel-angel/panel-angel.component';
import { PanelProtegeComponent } from './user/dashboard/panels/panel-protege/panel-protege.component';
import { AngelSpaceComponent } from './user/dashboard/spaces/angel-space/angel-space.component';
import { ProtegeSpaceComponent } from './user/dashboard/spaces/protege-space/protege-space.component';
import { ThankModalComponent } from './components/modals/thank-modal/thank-modal.component';
import { UncoverModalComponent } from './components/modals/uncover-modal/uncover-modal.component';
import { AchievementModalComponent } from './components/modals/achievement-modal/achievement-modal.component';

// CHAT
import { ChatComponent } from './components/chat/chat.component';
import { ChatDisplayComponent } from './components/chat/components/chat-display/chat-display.component';
import { ChatMessageComponent } from './components/chat/components/chat-message/chat-message.component';
import { ChatInputTxtComponent } from './components/chat/components/chat-input-txt/chat-input-txt.component';
import { ChatWithAngelComponent } from './components/chat/components/chat-with-angel/chat-with-angel.component';
import { ChatWithProtegeComponent } from './components/chat/components/chat-with-protege/chat-with-protege.component';
import { ChatWithAngelInputComponent } from './components/chat/components/chat-with-angel/chat-with-angel-input/chat-with-angel-input.component';
import { ChatWithAngelMessageComponent } from './components/chat/components/chat-with-angel/chat-with-angel-message/chat-with-angel-message.component';
import { ChatWithProtegeInputComponent } from './components/chat/components/chat-with-protege/chat-with-protege-input/chat-with-protege-input.component';
import { ChatWithProtegeMessageComponent } from './components/chat/components/chat-with-protege/chat-with-protege-message/chat-with-protege-message.component';
import { RegisterFormComponent } from './user/dashboard/register-user/register-form/register-form.component';
import { ChallengeModalComponent } from './components/modals/challenge-modal/challenge-modal.component';






@NgModule({
  declarations: [
    AppComponent,
    NavigationComponent,
    ItemsComponent,
    SliderComponent,
    AddItemComponent,
    EditItemComponent,
    FirebaseTestsComponent,
    StyleDirective,
    SigninAdminComponent,
    RegisterComponent,
    DashboardComponent,
    EditUserComponent,
    AddItemTestComponent,
    ReactiveFormComponent,
    FirebaseOperationsComponent,
    AddUserComponent,
    ListUserComponent,
    SigninUserComponent,
    UserDashboardComponent,
    RegisterUserComponent,
    ResetPasswordComponent,
    PanelHolderComponent,
    PanelAngelComponent,
    PanelProtegeComponent,
    AngelSpaceComponent,
    ProtegeSpaceComponent,
    ThankModalComponent,
    UncoverModalComponent,
    AchievementModalComponent,
    ChatComponent,
    ChatDisplayComponent,
    ChatMessageComponent,
    ChatInputTxtComponent,
    ChatWithAngelComponent,
    ChatWithProtegeComponent,
    ChatWithAngelInputComponent,
    ChatWithAngelMessageComponent,
    ChatWithProtegeInputComponent,
    ChatWithProtegeMessageComponent,
    RegisterFormComponent,
    ChallengeModalComponent
    


  ],
  imports: [
    BrowserModule,
    AppRoutingModule,
    MaterialModule,
    AngularFireModule.initializeApp(environment.firebaseConfig),
    AngularFirestoreModule,
    BrowserAnimationsModule,
    FormsModule,
    ReactiveFormsModule,
    PickerModule,
    EmojiModule,
    ImageCropperModule,
    AngularFireStorageModule
  ],
  providers: [ItemService, UsersService, ChatService],
  bootstrap: [AppComponent]
})
export class AppModule { }
