import { Component, OnInit } from '@angular/core';
import { FormGroup, FormBuilder, Validators } from '@angular/forms';
import { ChatService } from 'src/app/services/chat.service';
import { UsersService } from 'src/app/services/users.service';
import { Message } from 'src/app/models/message';
import { User } from 'src/app/models/user';

@Component({
  selector: 'app-chat-input-txt',
  templateUrl: './chat-input-txt.component.html',
  styleUrls: ['./chat-input-txt.component.css']
})
export class ChatInputTxtComponent implements OnInit {

  inputTxtForm : FormGroup

  message : Message = {
    author_id: '',
    author_email: '',
    author_surname: '',
    author_photo: '',
    chat_room_id: '',
    created: '',
    message: '',
    read: false

  }

  user : User
  userDatas: any[];

  // Emoji

  showEmojiPicker: boolean = false


  constructor(private chatService:ChatService, private usersService: UsersService, private formBuilder: FormBuilder) { }

  ngOnInit() {

    // Initialisation formulaire
    this.inputTxtForm = this.formBuilder.group({
      id: '',
      email: '',
      message: ['', Validators.required],
      author_id: '',
      author_surname: '',
      author_photo: '',
      chat_room_id: '',
      created: '',
      read: false

    

    })

    this.usersService.getConnectedUserDatas().subscribe(results =>
      {
        this.userDatas = results // Converting observable into array

      }
    )

    
  }


  submitForm(){

    // valeurs du formulaire
    this.message.message = this.inputTxtForm.value.message
    this.message.author_id = this.userDatas[0].id
    this.message.author_email = this.userDatas[0].email
    this.message.author_surname = this.userDatas[0].surname
    this.message.author_photo = this.userDatas[0].photo
    
    this.message.created = new Date();
    console.log(this.message.message)

    // on envoie l'objet message dans firestore
    this.chatService.addMessage(this.message)

    this.showEmojiPicker = false;

    //  On réinitialise les champs du formulaire
    this.inputTxtForm = this.formBuilder.group({
      id: '',
      email: '',
      message: '', 
      author_id: '',
      author_surname: '',
      author_photo: '',
      chat_room_id: '',
      created: '',
      read: false

    })
  }

  toggleEmojiPicker() {
    this.showEmojiPicker = !this.showEmojiPicker;
  }

  closeEmojiPicker() {
   

      this.showEmojiPicker = false;
   
    
  }

  addEmoji($event){
    let data = this.inputTxtForm.get('message');
    // xa0 add a space after emoji
    data.patchValue(data.value + $event.emoji.native + '\xa0\xa0\xa0')
  }

}
