import { Component, OnInit } from '@angular/core';
import { FormGroup, FormBuilder, Validators } from '@angular/forms';
import { ChatService } from 'src/app/services/chat.service';
import { AuthenticationService } from 'src/app/services/authentication.service';
import { Message } from 'src/app/models/message';
import { User } from 'src/app/models/user';
import { Chatroom } from 'src/app/models/chatroom';

@Component({
  selector: 'app-chat-with-angel-input',
  templateUrl: './chat-with-angel-input.component.html',
  styleUrls: ['./chat-with-angel-input.component.css']
})
export class ChatWithAngelInputComponent implements OnInit {
  
  inputTxtForm : FormGroup

  message : Message = {
    author_id: '',
    author_email: '',
    author_surname: '',
    author_photo: '',
    chat_room_id: '',
    created: '',
    message: '',
    read: false

  }

  // User datas
  user: User
  userDatas: any[];
  userEmail: string

  // Angel
  angel: User
  angelDatas$: any
  angelDatas: any[]
  angelId: string

  // Chat room
  chatRoomWithAngel: Chatroom
  chatRoomDatas: any []
  chatRoomId: string

  // Emoji

  showEmojiPickerAngel: boolean = false


  constructor(private chatService:ChatService, private authenticationService: AuthenticationService, private formBuilder: FormBuilder) { }

  ngOnInit() {

    // Initialisation formulaire
    this.inputTxtForm = this.formBuilder.group({
      id: '',
      email: '',
      message: ['', Validators.required],
      author_id: '',
      author_surname: '',
      author_photo: '',
      chat_room_id: '',
      created: '',
      read: false

    })

      // ON RECUPERE USER DEPUIS AUTHENTICATION SERVICE
      this.user = this.authenticationService.user
   
      // ON RECUPERE LA CHATROOM ID DEPUIS LE CHAT SERVICE
      this.chatRoomWithAngel = this.chatService.chatRoomWithAngel
     
      // ON RECUPERE AGEL DEPUIS AUTHENTICATION SERVICE
      this.angel = this.authenticationService.angel

  }

  submitForm(){

    // valeurs du formulaire
    this.message.message = this.inputTxtForm.value.message
    this.message.author_id = this.user.id
    this.message.author_email = this.user.email
    this.message.author_surname = this.user.surname
    this.message.author_photo = this.user.photo
    this.message.chat_room_id = this.chatRoomWithAngel.id
    this.message.created = new Date();

    // on envoie l'objet message dans firestore
    this.chatService.addMessage(this.message)

    // on incrémente le compteur de messages non lus du protégé
    this.chatService.incrementUnreadMsgFromProtegeCounter(this.angel.id)

    this.showEmojiPickerAngel = false;

    //  On réinitialise les champs du formulaire
    this.inputTxtForm = this.formBuilder.group({
      id: '',
      email: '',
      message: '', 
      author_id: '',
      author_surname: '',
      author_photo: '',
      chat_room_id: '',
      created: '',
      read: false

    })
  }

  toggleEmojiPicker() {
    this.showEmojiPickerAngel = !this.showEmojiPickerAngel;
  }

  closeEmojiPicker() {
      this.showEmojiPickerAngel = false;
  }

  addEmoji($event){
    let data = this.inputTxtForm.get('message');
    // xa0 add a space after emoji
    data.patchValue(data.value + $event.emoji.native + '\xa0\xa0\xa0')
  }

}