import { Component, OnInit, ViewChild, ElementRef, AfterViewChecked } from '@angular/core';
import { ChatService } from 'src/app/services/chat.service';
import { AuthenticationService } from 'src/app/services/authentication.service';
import { Chatroom } from 'src/app/models/chatroom';
import { User } from 'src/app/models/user';


@Component({
  selector: 'app-chat-with-angel',
  templateUrl: './chat-with-angel.component.html',
  styleUrls: ['./chat-with-angel.component.css']
})
export class ChatWithAngelComponent implements OnInit, AfterViewChecked {

  // la propriété feedContainer nous donne accès à l'élément référencé sous le nom 'scroller' dans le html
  @ViewChild('scroller') private feedContainer: ElementRef;

  // User datas
  user: User
  userDatas: any[]
  userId: string
  surname: string
  userPhoto: string
  userEmail: string
  numberOfMessages: number;

  // Chat room
  chatRoom: Chatroom
  chatRoomDatas: any []
  chatRoomId: string
  unreadMessages: any []
  numberOfUnreadMessages: number;

  // Messages
  angelSpaceMessages: any []

  container: HTMLElement;

  constructor(private chatService:ChatService, private authenticationService: AuthenticationService) { }

  ngOnInit() {

    this.container = document.getElementById("msgContainer");
              
    // ON RECUPERE USER DEPUIS AUTHENTICATION SERVICE
    this.user = this.authenticationService.user
    this.userId = this.user.id
    this.surname = this.user.surname
    this.userPhoto = this.user.photo

    // ON RECUPERE LA CHATROOM ID DEPUIS LE CHAT SERVICE
    this.chatRoom = this.chatService.chatRoomWithAngel
  
      // On recupere les messages
      this.chatService.getAngelChatMessages(this.chatRoom.id).subscribe( results => {
        this.angelSpaceMessages = results
        this.numberOfMessages = this.angelSpaceMessages.length
     
          }
        ) 

  }

  onDelete(id){
    this.chatService.deleteMessage(id)
  }

  scrollToBottom(): void {
    // scrollTop : gets or sets the number of pixels that an element content is scrolled vertically
    this.feedContainer.nativeElement.scrollTop = this.feedContainer.nativeElement.scrollHeight;
  }


  ngAfterViewChecked() {
    this.scrollToBottom();
  }

  
}
