import { Component, OnInit } from '@angular/core';
import { FormGroup, FormBuilder, Validators } from '@angular/forms';
import { ChatService } from 'src/app/services/chat.service';
import { AuthenticationService } from 'src/app/services/authentication.service';
import { Message } from 'src/app/models/message';
import { User } from 'src/app/models/user';
import { Chatroom } from 'src/app/models/chatroom';


@Component({
  selector: 'app-chat-with-protege-input',
  templateUrl: './chat-with-protege-input.component.html',
  styleUrls: ['./chat-with-protege-input.component.css']
})
export class ChatWithProtegeInputComponent implements OnInit {

  inputTxtForm : FormGroup

  message : Message = {
    author_id: '',
    author_email: '',
    author_surname: '',
    author_photo: '',
    chat_room_id: '',
    created: '',
    message: '',
    read: false

  }

  // User datas
  user: User
  userDatas: any[]

  // Chat room
  chatRoomWithProtege: Chatroom
  chatRoomDatas: any[]
  chatRoomId: string

  // Protege 
  protege: User
  protegeDatas$: any
  protegeDatas: any[]
  protegeEmail: string
  protegeId: string

  // Emoji

  showEmojiPicker: boolean = false

  constructor(private formBuilder: FormBuilder, private authenticationService: AuthenticationService, private chatService:ChatService) { }

  ngOnInit() {

    // Initialisation formulaire
    this.inputTxtForm = this.formBuilder.group({
      id: '',
      email: '',
      message: ['', Validators.required],
      author_id: '',
      author_surname: '',
      author_photo: '',
      chat_room_id: '',
      created: '',
      read: false
    })
    
  
    // ON RECUPERE USER DEPUIS AUTHENTICATION SERVICE
    this.user = this.authenticationService.user
   
    // ON RECUPERE LA CHATROOM ID DEPUIS LE CHAT SERVICE
    this.chatRoomWithProtege = this.chatService.chatRoomWithProtege
   
    this.protege = this.authenticationService.protege


  }

  submitForm(){

    // valeurs du formulaire
    this.message.message = this.inputTxtForm.value.message
    this.message.author_id = this.user.id
    this.message.author_email = this.user.email
    this.message.author_surname = this.user.surname
    this.message.author_photo = this.user.photo
    this.message.chat_room_id = this.chatRoomWithProtege.id
    this.message.created = new Date();
   
    // on envoie l'objet message dans firestore
    this.chatService.addMessage(this.message)

    // on incrémente le compteur de messages non lus du protégé
    this.chatService.incrementUnreadMsgFromAngelCounter(this.protege.id)

    this.showEmojiPicker = false;

    //  On réinitialise les champs du formulaire
    this.inputTxtForm = this.formBuilder.group({
      id: '',
      email: '',
      message: '', 
      author_id: '',
      author_surname: '',
      author_photo: '',
      chat_room_id: '',
      created: '',
      read: false

    })
  }

  toggleEmojiPicker() {
    this.showEmojiPicker = !this.showEmojiPicker;
  }

  closeEmojiPicker() {
      this.showEmojiPicker = false;
  }

  addEmoji($event){
    let data = this.inputTxtForm.get('message');
    // xa0 add a space after emoji
    data.patchValue(data.value + $event.emoji.native + '\xa0\xa0\xa0')
  }

}