import { Component, OnInit, ViewChild, ElementRef } from '@angular/core';
import { ChatService } from 'src/app/services/chat.service';
import { Chatroom } from 'src/app/models/chatroom';
import { AuthenticationService } from 'src/app/services/authentication.service';
import { User } from 'src/app/models/user';

@Component({
  selector: 'app-chat-with-protege',
  templateUrl: './chat-with-protege.component.html',
  styleUrls: ['./chat-with-protege.component.css']
})
export class ChatWithProtegeComponent implements OnInit {

  // la propriété feedContainer nous donne accès à l'élément référencé sous le nom 'scroller' dans le html
  @ViewChild('scroller') private feedContainer: ElementRef;

  // User datas
  user: User
  userDatas: any[]
  userId: string
  surname: string
  userPhoto: string
  userEmail: string

  // Chat room
  chatRoomDatas: any []
  chatRoom: Chatroom
  chatRoomId: string

  // Messages
  protegeSpaceMessages: any []
  numberOfMessages: number;

  container: HTMLElement;

  constructor(private chatService:ChatService, private authenticationService: AuthenticationService) { }

  ngOnInit() {

    this.container = document.getElementById("msgContainer");           
    this.container.scrollTop = this.container.scrollHeight;  

    // ON RECUPERE USER DEPUIS AUTHENTICATION SERVICE
    this.user = this.authenticationService.user
    this.userId = this.user.id
    this.surname = this.user.surname
    this.userPhoto = this.user.photo
    
    // ON RECUPERE LA CHATROOM ID DEPUIS LE CHAT SERVICE
    this.chatRoom = this.chatService.chatRoomWithProtege

     // On recupere les messages
     this.chatService.getProtegeChatMessages(this.chatRoom.id).subscribe( results => 
        {
        this.protegeSpaceMessages = results
        this.numberOfMessages = this.protegeSpaceMessages.length
        }
      ) 

  }

  onDelete(id){
    this.chatService.deleteMessage(id)
  }

  scrollToBottom(): void {

    // scrollTop : gets or sets the number of pixels that an element content is scrolled vertically
    this.feedContainer.nativeElement.scrollTop = this.feedContainer.nativeElement.scrollHeight;
  }

  ngAfterViewChecked() {

    this.scrollToBottom();

  }



}
