import { Component, OnInit } from '@angular/core';
import { FormBuilder,FormGroup, Validators } from '@angular/forms';
import { UsersService } from 'src/app/services/users.service';

@Component({
  selector: 'app-uncover-modal',
  templateUrl: './uncover-modal.component.html',
  styleUrls: ['./uncover-modal.component.css']
})
export class UncoverModalComponent implements OnInit {

  // USER
  userDatas: any[]
  userEmail: string
  uncoverAttempts: number
  userId: string

  // PROTECTOR
  protectorDatas: any []
  protectorName: string
  protectorSurname: string
  protectorId: string;

  // FORM
  uncoverForm: FormGroup

  formSubmitted: boolean = false;
  formSuccess: boolean = false;

  protectorFound: boolean = false;
  protectorNotFound: boolean = false;

  

  constructor(private usersService: UsersService, private formBuilder: FormBuilder) { }

  ngOnInit() {


    this.uncoverForm = this.formBuilder.group({
      name: ['', [Validators.required]],
      surname: ['', [Validators.required]]
    });

   

    this.usersService.getConnectedUserDatas().subscribe( results=>
      {
        this.userDatas = results
        this.userEmail = this.userDatas[0].email
        this.userId = this.userDatas[0].id
        this.uncoverAttempts = this.userDatas[0].uncover_attempts
        
        this.usersService.getProtectorUserDatas(this.userEmail).subscribe( results => 
          {
            this.protectorDatas = results
            this.protectorName = this.protectorDatas[0].name
            this.protectorSurname = this.protectorDatas[0].surname
            this.protectorId = this.protectorDatas[0].id

          }
          )

      }
      )

  }


  submitUncover(data){

    if (data.name === this.protectorName)
    { 
      this.protectorFound = true
      this.usersService.setUserToDiscovered(this.protectorId)
    }

    else if (data.name != this.protectorName)
    { 
      this.protectorNotFound = true
      if(this.uncoverAttempts <= 2) {
        this.usersService.incrementAttemps(this.userId)
      }
      
    }


    this.formSubmitted = true
    this.formSuccess = true

    //  On réinitialise les champs du formulaire
    this.uncoverForm = this.formBuilder.group({
      name: ['', [Validators.required]], 
      surname: ['', [Validators.required]]
    })
 
  }

  tryAgain() {
    this.protectorNotFound = false
    this.formSubmitted = false

    this.uncoverForm = this.formBuilder.group({
      name: ['', [Validators.required]], 
      surname: ['', [Validators.required]]
    })
  }

 

}
