import { Injectable } from '@angular/core';
import { AngularFirestore, AngularFirestoreCollection, AngularFirestoreCollectionGroup, AngularFirestoreDocument } from '@angular/fire/firestore';
import * as firebase from 'firebase';
import { Router } from '@angular/router';
import { User } from 'src/app/models/user'
import { Observable } from 'rxjs';
import { take } from 'rxjs/operators';


@Injectable({
  providedIn: 'root'
})
export class AuthenticationService {

  // DOCUMENT
  userSessionEmail: string;
  currentUserEmail: string;
  currentUser$: Observable<User>;
  connectedUserDatas$: Observable<User>;
  userDatas: User[];
  user: User
 
 
  // USER COLLECTION
  userCollection: AngularFirestoreCollection<User>;
  userCollectionObs$: Observable<User[]>;


   // PROTEGE DATAS
   protegeCollection: AngularFirestoreCollection<User>;
   protegeCollectionObs$: Observable<User[]>;
   protegeDatas: any[];
   protege: User;

   // ANGEL DATAS
   angelCollection: AngularFirestoreCollection<User>;
   angelCollectionObs$: Observable<User[]>;
   angelDatas: any[];
   angel: User;


  constructor(
    private router: Router,
    public afs: AngularFirestore
  ) { }

  // ON CREE UNE METHODE QUI RETOURNE UNE PROMISE, THEN => quand tout s'est bien passé, ON UTILISE LE CATCH SI ERREUR

  createUser (email:string, password:string){
    return new Promise(
      (resolve, reject) => {
        firebase.auth().createUserWithEmailAndPassword(email, password).catch(
          (error) => {
            reject(error);
          }
        )
        
      }
    )
  }

  signInUser (email:string, password:string){
   
        return firebase.auth().signInWithEmailAndPassword(email, password)
 
  }


  signInAdmin (email:string, password:string){
    return new Promise(
      (resolve, reject) => {
        firebase.auth().signInWithEmailAndPassword(email, password)
        
        .then(
          (data) => {
            
            resolve(data);

            

          }
          
        )
        .catch(
          (error) => {
            reject(error);
          }
        )
      }
    )

    
  }

  
  // USER

  getCurrentUserDatasOneShot() {
    this.userSessionEmail = firebase.auth().currentUser.email
    this.userCollection = this.afs.collection('users', ref => ref.where('email', '==', this.userSessionEmail));
    this.userCollectionObs$ = this.userCollection.valueChanges({ idField: 'id' })

    return this.userCollectionObs$.pipe(take(1)).toPromise().then( results => 
        {
          this.userDatas = results
          this.user = this.userDatas[0]

          
        }
        
      )

  }

  getCurrentUserDatas() {
    this.userSessionEmail = firebase.auth().currentUser.email
    this.userCollection = this.afs.collection('users', ref => ref.where('email', '==', this.userSessionEmail));
    this.userCollectionObs$ = this.userCollection.valueChanges({ idField: 'id' })

    return this.userCollectionObs$.subscribe( results => 
        {
          this.userDatas = results
          this.user = this.userDatas[0]

          
        }
        
      )

  }

  // PROTEGE 

  getProtegeUserDatas(protegeEmail){
    this.protegeCollection = this.afs.collection('users', ref => ref.where('email', '==', protegeEmail));
    
    this.protegeCollectionObs$ = this.protegeCollection.valueChanges({ idField: 'id' })
  
    return this.protegeCollectionObs$.pipe(take(1)).toPromise().then( datas =>
        {
          this.protegeDatas = datas
          this.protege = this.protegeDatas[0]
          
        }
      )

  }

  // ANGEL

  getAngelUserDatas(angelEmail){
    this.angelCollection = this.afs.collection('users', ref => ref.where('email', '==', angelEmail));
    
    this.angelCollectionObs$ = this.angelCollection.valueChanges({ idField: 'id' })
  
    return this.angelCollectionObs$.pipe(take(1)).toPromise().then( datas =>
        {
          this.angelDatas = datas
          this.angel = this.angelDatas[0]
          
        }
      )

  }


  signOutUser(){
    firebase.auth().signOut()
    this.router.navigate(['signin-user']) //navigue vers sign in
  }


}
