import { Injectable } from '@angular/core';
import { AngularFirestore, AngularFirestoreCollection, AngularFirestoreDocument } from '@angular/fire/firestore';
import { Chatroom } from 'src/app/models/chatroom';
import * as firebase from 'firebase';
import { Observable } from 'rxjs';
import { take } from 'rxjs/operators';


@Injectable({
  providedIn: 'root'
})

export class ChatService {

  userSessionEmail: string;

  // CHAT ROOM WITH PROTEGE
  chatRoomWithProtegeCollection: AngularFirestoreCollection<Chatroom>;
  chatRoomWithProtegeCollectionObs$: Observable<Chatroom[]>;
  chatRoomWithProtegeDatas: Chatroom[];
  chatRoomWithProtege: Chatroom

  // CHAT ROOM WITH ANGEL
  chatRoomWithAngelCollection: AngularFirestoreCollection<Chatroom>;
  chatRoomWithAngelCollectionObs$: Observable<Chatroom[]>;
  chatRoomWithAngelDatas: Chatroom[];
  chatRoomWithAngel: Chatroom



  constructor(public afs: AngularFirestore) { }



  addMessage(data) {
    this.afs
    .collection("message")
    .add(data)
  }

  getMessages() {

    return this.afs.collection('message', ref => ref.orderBy('created', 'asc')).valueChanges( { idField: 'id' } )

  }

  getConnectedUserDatas(){
    
    this.userSessionEmail = firebase.auth().currentUser.email
    return this.afs.collection('users', ref => ref.where('email', '==', this.userSessionEmail)).valueChanges( { idField: 'id' } );
    
  }

  getProtegeUserDatas(userToProtect){
    return this.afs.collection('users', ref => ref.where('email', '==', userToProtect)).valueChanges( { idField: 'id' } );
    
  }


  // On récupère les infos de l'ange gardien
  getProtectorUserDatas(userEmail){
    return this.afs.collection('users', ref => ref.where('userToProtect', '==', userEmail)).valueChanges( { idField: 'id' } );
  }

  // ANGEL SPACE
  // FINAL CODE WORKING
  getAngelChatId(userEmail){

    this.chatRoomWithAngelCollection = this.afs.collection('chat_room', ref => ref.where('protected_email', '==', userEmail));

    this.chatRoomWithAngelCollectionObs$ = this.chatRoomWithAngelCollection.valueChanges({ idField: 'id' })

    return this.chatRoomWithAngelCollectionObs$.pipe(take(1)).toPromise().then( results =>
        {
          this.chatRoomWithAngelDatas = results
          this.chatRoomWithAngel = this.chatRoomWithAngelDatas[0]
        }
      )
  }
  // CHECK IF STILL IN USE ?
  getChatRoomId(userEmail){
    return this.afs.collection('chat_room', ref => ref.where('protected_email', '==', userEmail)).valueChanges( { idField: 'id' } );
  }

  getAngelChatMessages(chatRoomId) {
    return this.afs.collection('message', ref => ref.where('chat_room_id', '==', chatRoomId).orderBy('created', 'asc').limit(50)).valueChanges( { idField: 'id' } )
  }

  incrementUnreadMsgFromAngelCounter(userId){
   
    this.afs.doc('users/' + userId).update({unreadMessagesFromAngel : firebase.firestore.FieldValue.increment(1) });
   
  }

  // PROTEGE SPACE

  // FINAL CODE WORKING
  getProtegeChatId(userEmail){

    this.chatRoomWithProtegeCollection = this.afs.collection('chat_room', ref => ref.where('angel_email', '==', userEmail));

    this.chatRoomWithProtegeCollectionObs$ = this.chatRoomWithProtegeCollection.valueChanges({ idField: 'id' })

    return this.chatRoomWithProtegeCollectionObs$.pipe(take(1)).toPromise().then( results =>
        {
          this.chatRoomWithProtegeDatas = results
          this.chatRoomWithProtege = this.chatRoomWithProtegeDatas[0]
        }
      )
  }

  getProtegeChatMessages(chatRoomId) {
    return this.afs.collection('message', ref => ref.where('chat_room_id', '==', chatRoomId).orderBy('created', 'asc').limit(50)).valueChanges( { idField: 'id' } )
  }

  incrementUnreadMsgFromProtegeCounter(userId){
   
    this.afs.doc('users/' + userId).update({unreadMessagesFromProtege : firebase.firestore.FieldValue.increment(1) });
    
  }

  // RESET UNREAD MESSAGES COUNTERS

  resetCounters(userId){
    this.afs.doc('users/' + userId).update({unreadMessagesFromProtege: 0});
    this.afs.doc('users/' + userId).update({unreadMessagesFromAngel: 0});
  }


  // On récupère les messages
  getAngelSpaceMessages(){
    return this.afs.collection('message', ref => ref.where('userToProtect', '==', 'freelance@logeen.com').orderBy('created', 'asc')).valueChanges( { idField: 'id' } )
  }


  deleteMessage(id){
   this.afs.doc('message/' + id).delete();
  }
 


}
