import { Injectable } from '@angular/core';
import { AngularFirestore, AngularFirestoreCollection, AngularFirestoreDocument } from '@angular/fire/firestore';
// import { Item } from '../models/item';
import { Observable } from 'rxjs';
import * as firebase from 'firebase';





//  On definit la structure des datas de Item
interface Item {
  // ? signifie que la valeur est optionelle 
  id?: string;
  email?: string;
  message?: string;
  name?: string;
  comment?: string;
}



@Injectable({
  providedIn: 'root'
})

export class ItemService {

  itemToDelete: any
  

  // 1 On fait reference a une collection (qui est une liste de documents)
  itemsCollection: AngularFirestoreCollection<Item>;
  
  // 2 On recupere les donnees dans un observable qui est un array de Item
  items: Observable<Item[]>;

  // On definit un document pour pouvoir delete ou update ensuite
  itemDoc: AngularFirestoreDocument<Item>



  constructor(public afs: AngularFirestore) { 

    // this.items = this.afs.collection('contacts').valueChanges();
    // 3 On va chercher les elements dans firebase et on les stocke dans itemCollection

    // METHODE VALUE CHANGES
    
    // TOUTES LES VALEURS
    this.itemsCollection = this.afs.collection('contacts')

    // METHODE POUR RECUPERER UNIQUEMENT CERTAINS CHAMPS
    // this.itemsCollection = this.afs.collection('contacts', ref => {
    //   return ref.where('name', '==','RENE')
    // })

    // idField: 'id' permet de recuperer la valeur du champ ID avec la methode valueChanges
    this.items = this.itemsCollection.valueChanges( { idField: 'id' } )
    


    // METHODE SNAPSHOTCHANGES
    // this.itemsCollection = this.afs.collection('contacts', ref => ref.orderBy('email', 'asc'))


    // this.items = this.itemsCollection.snapshotChanges().pipe(
    //   map(changes => {
    //     return changes.map (a => {
    //       const data = a.payload.doc.data() as Item
    //       data.id = a.payload.doc.id
    //       return data
    //     })
    //   }

    //   )
    // )

  }


  getItems() {
    return this.items;
  }

  getItemsById(data) {
    return this.afs
    // .collection('contacts')
    .doc('contacts/' + data)
    .valueChanges();
    
    
  }

  addItem(item: Item) {
    this.itemsCollection.add(item);
   
  }

  updateItem(item_id){
    this.afs.doc('contacts/' + item_id).update;
  }

  deleteItem(item_id) {
   
    //this.itemToDelete = this.afs.doc('contacts/' + item_id);
    // this.itemToDelete
    // .get()
    // .then(doc => {
    //   console.log(doc.data())
    // })
    //const storageRef = firebase.storage().refFromURL(this.fileLink);
    //console.log(refPhoto)

    this.afs.doc('contacts/' + item_id).delete();
    
  }

  createItem(data) {
        this.afs
            .collection("contacts")
            .add(data)  
   
  }

  uploadFile(file: File) {
    return new Promise(
      (resolve, reject) => {
        const uniqueId = Date.now().toString();
        const fileName = uniqueId + file.name;
        const upload = firebase.storage().ref().child('images/' + fileName).put(file);
        upload.on(firebase.storage.TaskEvent.STATE_CHANGED,
          () =>  {
            console.log('Chargement ...'); // Fonction anonyme 1) Pending = en attente de réponse
          },
          (error) => {
            console.log(error); // Fonction anonyme 2) Error = en cas d'erreur
            reject(error);
          },
          () => {
            upload.snapshot.ref.getDownloadURL().then(
              (downloadUrl) => {
                resolve(downloadUrl);
              }
            ) //// Fonction anonyme 3) Succes = on recupere le lien du fichier
          }
          ); // Ecoute la base de données pour sa réponse
      }
    );
  }


  fileLink:string  // Supression d'une image du storage
  removeFile (){
    //this.fileLink = 'https://firebasestorage.googleapis.com/v0/b/coffee-app-76b18.appspot.com/o/images%2F1598333794506Capture%20d%E2%80%99e%CC%81cran%202019-06-14%20a%CC%80%2010.43.44.jpg?alt=media&token=c2259739-73fe-4f61-953a-4f43fe6ea3c5'
    // if(this.fileLink) {
    const storageRef = firebase.storage().refFromURL(this.fileLink); // recupere le chemin dans la base de données de l'image a partir de son lien
    storageRef.delete()
    console.log(this.fileLink)
    console.log('SUPPRESSION OK')
    // }
    
  }

  removeField(id_data){   // Définit le champ photo de la base firestore comme vide losqu'une image est supprimée
    console.log('REMOVE FIELD OK' + id_data)
    
    this.afs.doc('contacts/' + id_data).update({    // reference du document firestore à modifier
      // photo: firebase.firestore.FieldValue.delete()
      photo: null
    });
 

    
  }



}

