import { Injectable } from '@angular/core';
import { AngularFirestore, AngularFirestoreCollection, AngularFirestoreDocument } from '@angular/fire/firestore';
import { Observable } from 'rxjs';
import * as firebase from 'firebase';
import { User } from 'src/app/models/user'
import { Router } from '@angular/router';
import { take } from 'rxjs/operators';


//  On definit la structure des datas de Users


@Injectable({
  providedIn: 'root'
})
export class UsersService {



  // 1) On fait reference a une collection (qui est une liste de documents)
  usersCollection: AngularFirestoreCollection<User[]>;

  //emailsCollection: AngularFirestoreCollection<Emails>;

  connectedUserCollection: AngularFirestoreCollection<User>;

  // 2) On recupere les donnees dans un observable qui est un array de Users
  users: Observable<User[]>;
  emailToCheck: string;
  duplicateEmail: Observable<User[]>;
  singleUser$: Observable<User[]>;

  userToDelete: any;

  connectedUserEmail: any;


  // USER DATAS
  userDatas: any;
  userSessionEmail: string = '';

  // PROTEGE DATAS
  protegeCollection: AngularFirestoreCollection<User>;
  protegeCollectionObs$: Observable<User[]>;
  protegeId: string;
  protegeDatas: any[];
  protege: User;
  company: string;

  // ADMIN
  protegeCollectionForAdmin: AngularFirestoreCollection<User>;
  protegeCollectionForAdminObs$: Observable<User[]>;
  protegeForAdminDatas: any[];
  protegeForAdmin: User;
  protegeForAdminEmail: string;

  // DUPLICATEEMAIL
  duplicateEmailCollection: AngularFirestoreCollection<any>
  duplicateEmailCollectionObs$: Observable<any[]>;
  duplicateEmailDatas: any[];


  constructor(public afs: AngularFirestore, private router: Router) { }

  getUsers() {
    return this.afs.collection('users', ref => ref.orderBy('name', 'asc')).valueChanges({ idField: 'id' })
  }

  getProteges() {
    return this.afs.collection('users', ref => ref.where('protectedByUser', '==', '').orderBy('name', 'asc')).valueChanges({ idField: 'id' })
  }

  getCompanies() {
    return this.afs.collection('companies', ref => ref.orderBy('name', 'asc')).valueChanges().pipe(take(1))
  }

  getUsersByCompany(value) {
    return this.afs.collection('users', ref => ref.where('companies', '==', value).orderBy('name', 'asc')).valueChanges({ idField: 'id' })
  }


  // On récupère l'email de l'utilisateur connecté


  setUserEmail() {

    this.userSessionEmail = firebase.auth().currentUser.email
    return this.userSessionEmail

  }


  // Recupere les datas de l'utilisateur connecté et l'id .valueChanges( { idField: 'id' } )
  getConnectedUserDatas() {

    this.userSessionEmail = firebase.auth().currentUser.email
    return this.afs.collection('users', ref => ref.where('email', '==', this.userSessionEmail)).valueChanges({ idField: 'id' });

  }

  // On récupère les infos de l'ange gardien
  getProtectorUserDatas(userEmail) {
    return this.afs.collection('users', ref => ref.where('userToProtect', '==', userEmail)).valueChanges({ idField: 'id' });
  }


  // Recupere les datas du protege en passant son email
  getProtegeUserDatas(protegeEmail) {

    this.protegeCollection = this.afs.collection('users', ref => ref.where('userToProtect', '==', protegeEmail));
    this.protegeCollectionObs$ = this.protegeCollection.valueChanges()
    this.protegeCollectionObs$.subscribe(datas => {
      this.protegeDatas = datas
      this.protege = this.protegeDatas[0]

    }
    )
    return this.protege
  }

  checkDuplicateEmail(emailToCheck) {
    this.duplicateEmailCollection = this.afs.collection('users', ref => ref.where('email', '==', emailToCheck))
    this.duplicateEmailCollectionObs$ = this.duplicateEmailCollection.valueChanges().pipe(take(1))
    return this.duplicateEmailCollectionObs$

  }



  deleteUser(user_id) {

    this.afs.doc('users/' + user_id).delete();

  }

  // définit l'humeur
  setMood(userId, moodValue) {
    this.afs.doc('users/' + userId).update({ mood: moodValue });
  }

  setMood2(userId, moodValue) {
    //const userId = firebase.auth().currentUser.uid
    this.afs.doc('users/' + userId).update({ mood: moodValue });
  }

  // Uncover
  incrementAttemps(user_id) {
    this.userSessionEmail = firebase.auth().currentUser.email

    const userRef = this.afs.doc('users/' + user_id);
    const increaseBy = firebase.firestore.FieldValue.increment(1);
    userRef.update({ uncover_attempts: increaseBy });

  }

  setUserToDiscovered(protectorId) {
    this.afs.doc('users/' + protectorId).update({ incognito: false });
  }

  // ADMIN 
  //


  affectUserToProtectToUser(user_id, email) {
    const docRef = this.afs.doc('users/' + user_id).get
    this.afs.doc('users/' + user_id).update({ userToProtect: email })
  }



  setProtegeAsProtected(protegeId, protectorEmail) {
    this.afs.doc('users/' + protegeId).update({ protectedByUser: protectorEmail })
  }


  // Recupere les datas du protege en passant son email
  getProtegeUserDatasForAdmin(protegeId) {

    this.protegeCollectionForAdmin = this.afs.collection('users', ref => ref.where('email', '==', 'a@a.com'));
    this.protegeCollectionForAdminObs$ = this.protegeCollectionForAdmin.valueChanges({ idField: 'id' })
    this.protegeCollectionForAdminObs$.subscribe(datas => {
      this.protegeForAdminDatas = datas
      this.protegeForAdmin = this.protegeForAdminDatas[0]

    }
    )

    return this.protegeForAdmin

  }


  // Add badges
  addGenerosite(user_id) {
    this.afs.doc('users/' + user_id).update({ badge_generosite: '1.png' });
  }

  addGentillesse(user_id) {
    this.afs.doc('users/' + user_id).update({ badge_gentillesse: '2.png' });
  }

  addHumour(user_id) {
    this.afs.doc('users/' + user_id).update({ badge_humour: '3.png' });
  }

  addJoieDeVivre(user_id) {
    this.afs.doc('users/' + user_id).update({ badge_joie_de_vivre: '4.png' });
  }

  addSherlock(user_id) {
    this.afs.doc('users/' + user_id).update({ badge_sherlock: '5.png' });
  }

  uploadFile(file: File) {
    return new Promise(
      (resolve, reject) => {

        const uniqueId = Date.now().toString();
        const fileName = uniqueId + file.name;

        const upload = firebase.storage().ref().child('images/' + fileName).put(file);
        upload.on(firebase.storage.TaskEvent.STATE_CHANGED,
          () => {
            // console.log('Chargement ...'); // Fonction anonyme 1) Pending = en attente de réponse
          },
          (error) => {
            console.log(error); // Fonction anonyme 2) Error = en cas d'erreur
            reject(error);
          },
          () => {
            upload.snapshot.ref.getDownloadURL().then(
              (downloadUrl) => {
                resolve(downloadUrl);
              }
            ) //// Fonction anonyme 3) Succes = on recupere le lien du fichier
          }
        ); // Ecoute la base de données pour sa réponse
      }
    );
  }

  uploadCroppedFile(file: File, originalFileName) {
    return new Promise(
      (resolve, reject) => {

        const uniqueId = Date.now().toString();
        const fileName = uniqueId + originalFileName;

        const upload = firebase.storage().ref().child('images/' + fileName).put(file);
        upload.on(firebase.storage.TaskEvent.STATE_CHANGED,
          () => {
            // console.log('Chargement ...'); // Fonction anonyme 1) Pending = en attente de réponse
          },
          (error) => {
            console.log(error); // Fonction anonyme 2) Error = en cas d'erreur
            reject(error);
          },
          () => {
            upload.snapshot.ref.getDownloadURL().then(
              (downloadUrl) => {
                resolve(downloadUrl);
              }
            ) //// Fonction anonyme 3) Succes = on recupere le lien du fichier
          }
        ); // Ecoute la base de données pour sa réponse
      }
    );
  }


}
