import { Component, OnInit, OnDestroy } from '@angular/core';
import { UsersService } from 'src/app/services/users.service';
import { AuthenticationService } from 'src/app/services/authentication.service';
import { User } from 'src/app/models/user'
import {MatSnackBar,MatSnackBarHorizontalPosition, MatSnackBarVerticalPosition,} from '@angular/material/snack-bar';
import { ChatService } from 'src/app/services/chat.service';

@Component({
  selector: 'app-panel-angel',
  templateUrl: './panel-angel.component.html',
  styleUrls: ['./panel-angel.component.css']
})
export class PanelAngelComponent implements OnInit {

  // Snackbar
  horizontalPosition: MatSnackBarHorizontalPosition = 'center';
  verticalPosition: MatSnackBarVerticalPosition = 'top';
  snackMessage: string;

  // sliderValue: number = 30;
  mood: number = 10

  // User datas from firebase
  userDatas: any[]
  user: User
  userEmail: string
  userId: string
  sex : string
  unreadMessages: number
  unreadMessagesFromProtege: number
  unreadMessagesFromAngel: number

  // Chatbox
  chatOpen : boolean = true

  // Protector
  protectorDatas: any
  incognito: boolean
  protectorPhoto: string

  constructor(private usersService: UsersService, private _snackBar: MatSnackBar, private authenticationService: AuthenticationService, private chatService: ChatService) { }

  ngOnInit() {
    
    // On recupere les proprietes de connected user depuis authentication service

    this.user = this.authenticationService.user
    this.userEmail = this.user.email
    this.userId = this.user.id
    this.mood = this.user.mood
    this.sex = this.user.sex
    
    this.unreadMessagesFromProtege = this.user.unreadMessagesFromProtege
    this.unreadMessagesFromAngel = this.user.unreadMessagesFromAngel

    
    
    this.snackMessage =  this.unreadMessagesFromAngel + " nouveaux messages de votre Ange Gardien !" + "\n" + this.unreadMessagesFromProtege + " nouveaux messages de votre Protégé !"
    console.log(this.snackMessage )

    // Notifications nouveaux messages
    if(this.unreadMessagesFromProtege != 0 || this.unreadMessagesFromAngel != 0) {
      this.notificationBar()
    }
    

   

    this.usersService.getProtectorUserDatas(this.userEmail).subscribe( results => 
      {
        this.protectorDatas = results
        this.incognito = this.protectorDatas[0].incognito
        this.protectorPhoto = this.protectorDatas[0].photo
        //console.log('Incognito ?', this.protectorDatas[0].incognito)

      }
      )
   
  }
  
 

  getSliderValue(event){
    this.mood =  event.value;
  }

  setMoodValue(){
   this.usersService.setMood(this.user.id, this.mood)
  }

  displayRegisterForm(){}
  
  revealChatBox(){
    const element = document.querySelector('.revealTriggerAngel');
    element.classList.remove('effect-out');
    element.classList.add('effect-in');
    this.chatOpen = true;

  }

  hideChatBox(){
    const element = document.querySelector('.hideTriggerAngel');
    element.classList.remove('effect-in');
    element.classList.add('effect-out');
    this.chatOpen = false;
  }

  openSnackBar() {
    this._snackBar.open('Votre humeur est modifiée', '', {
      duration: 5000,
      panelClass: ['toast-white-style'],
      horizontalPosition: this.horizontalPosition,
      verticalPosition: this.verticalPosition,
    });
  }

  notificationBar(){
    this._snackBar.open(this.snackMessage, 'X', {
      duration: 8000,
      panelClass: ['toast-white-style'],
      horizontalPosition: this.horizontalPosition,
      verticalPosition: this.verticalPosition,
    });
    
    this.chatService.resetCounters(this.userId)
  }

  
  

}
