import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { AngularFirestore } from '@angular/fire/firestore';
import { Router } from '@angular/router';
import { UsersService } from 'src/app/services/users.service';
import * as firebase from 'firebase';
import { User } from 'src/app/models/user';
import { ImageCroppedEvent, base64ToFile } from 'ngx-image-cropper';
import { AuthenticationService } from 'src/app/services/authentication.service';

@Component({
  selector: 'app-register-form',
  templateUrl: './register-form.component.html',
  styleUrls: ['./register-form.component.css']
})
export class RegisterFormComponent implements OnInit {
  
  

  // Parametres pour upload images
  photoUploading = false;
  photoUploaded = false;
  photoUrl: string;

  //CROPPER

  imageChangedEvent: any = '';
  croppedImage: any = '';
  testImage: any;
  fileToReturn: any;
  fileLoaded: boolean = false;

  // Parametres user
  
  email:string;
  id_User: string;
  userDatas: any[];

  // Parametres form
  registerForm: FormGroup
  user : User = {
    id: '',
    name: '',
    surname: '',
    birthDate: '',
    arrivalDate: '',
    position: '',
    interests: '',
    description: '',
    email: '',
    password: '',
    photo: '',
    companies: '',
    role: '',
    profileComplete: true,
  
  }

  formSubmitted: boolean = false;
  formSuccess: boolean = false;

  //interests = ['Football', 'Tennis', 'Parachutisme', 'Velo', 'Autre']

  // RESET PASSWORD
  resetAsked : boolean = false;

  // AFFICHAGE OU DESAFFICHAGE EDIT USER FORM
  // editUserDisplay: boolean;

  constructor( 
    private formBuilder: FormBuilder, 
    public afs: AngularFirestore, 
    private usersService: UsersService
    ) { }

  ngOnInit() {

    

    this.registerForm = this.formBuilder.group({
      name: '',
      surname: '',
      birthDate: '',
      arrivalDate: '',
      position: '',
      interests: '',
      description: '',
      email: '',
      password: '',
      photo: '',
      profileComplete: true
    });

    this.usersService.getConnectedUserDatas().subscribe(results =>
      {
        this.userDatas = results // Converting observable into array
        this.user.email = this.userDatas[0].email
        this.user.name = this.userDatas[0].name
        this.user.surname = this.userDatas[0].surname
        this.user.birthDate = this.userDatas[0].birthDate
        this.user.arrivalDate = this.userDatas[0].arrivalDate
        this.user.position = this.userDatas[0].position
        this.user.description = this.userDatas[0].description
        this.user.interests = this.userDatas[0].interests
        this.id_User = this.userDatas[0].id
        this.user.companies = this.userDatas[0].companies
        this.user.photo = this.userDatas[0].photo
        

        this.email = this.userDatas[0].email // on définit une variable email globale pour le password reset
        
          // initialise les valeurs du formulaire
          this.registerForm.setValue({
      
            name: this.user.name,
            surname: this.user.surname,
            birthDate: this.user.birthDate,
            arrivalDate: this.user.arrivalDate,
            position: this.user.position,
            interests: this.user.interests,
            description: this.user.description,
            email: this.user.email,
            password: '',
            photo: this.user.photo,
            profileComplete: true

          })
        
      }
    )

  
    
  }

  submitRegisterUser(data){

    
    //const uniqueId = Date.now().toString();
    //const fileName = uniqueId + this.imageChangedEvent.target.files[0].name;
    //firebase.storage().ref().child('images/' + fileName).put(this.fileToReturn);
   
      this.afs.doc('users/' + this.id_User).update(data); // working version
      

      if(this.fileLoaded === true){
        this.usersService.uploadCroppedFile(this.fileToReturn, this.imageChangedEvent.target.files[0].name).then(
          (url: string) => {
            this.photoUrl = url;
            console.log('this.photoUrl from cropped image', this.photoUrl)
            this.photoUploading = false;
            this.photoUploaded = true;
            this.user.photo = this.photoUrl ? this.photoUrl : ''// On ajoute la valeur url de la photo dans l'objet item si elle existe, sinon on insere une valeur vide
            
    
            if(this.photoUrl) {
              this.afs.doc('users/' + this.id_User).update({photo: this.photoUrl}); // pour photo
            }
    
           
          }
        )
      }

      this.formSubmitted = true
      this.formSuccess = true
      
   
   
  }

  closeModal(){
    this.formSubmitted = false
    this.formSuccess = false
  }

  resetPassword(){
    firebase.auth().sendPasswordResetEmail(this.email)
    .then(() => this.resetAsked = true )
    .catch((error) => console.log(error))
    
  }
  
  fileChangeEvent(event) {
    this.photoUploading = true;
    this.imageChangedEvent = event;
    //let file: File = this.fileToReturn;

    this.usersService.uploadFile(this.imageChangedEvent.target.files[0]).then(
      (url: string) => {
        this.photoUrl = url;
        this.photoUploading = false;
        this.photoUploaded = true;
        this.fileLoaded = true;
      }
    )

 
  } 
  
  // CROPPER METHODS

    imageCropped(event: ImageCroppedEvent) {
        this.croppedImage = event.base64;
        this.fileToReturn = base64ToFile(this.croppedImage);
        //console.log('fileToReturn cropped:', this.fileToReturn)
     
    }


    
    imageLoaded() {
        // show cropper
    }
    cropperReady() {
        // cropper ready
    }
    loadImageFailed() {
        // show message
    }



}
