import { Component, OnInit, NgZone } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { Router } from '@angular/router';
import { UsersService } from 'src/app/services/users.service';
import { AngularFirestore } from '@angular/fire/firestore';
import * as firebase from 'firebase';
import { User } from 'src/app/models/user';


@Component({
  selector: 'app-reset-password',
  templateUrl: './reset-password.component.html',
  styleUrls: ['./reset-password.component.css']
})
export class ResetPasswordComponent implements OnInit {

  resetPasswordForm: FormGroup
  resetAsked: boolean = false
  resetPasswordDone: boolean = false
  emailToReset: string

  constructor(
    private formBuilder: FormBuilder, 
    public afs: AngularFirestore, 
    private usersService: UsersService,
    private router: Router) { }

  ngOnInit() {

    this.resetPasswordForm = this.formBuilder.group({
      email: ['', [Validators.required, Validators.email]]
    });

    this.resetPasswordDone = false


  }

  setResetAsked(){
    this.resetAsked = true
    console.log(this.resetAsked)
  }

  submitResetPasswordForm(){

    const email = this.resetPasswordForm.get('email').value;
    firebase.auth().sendPasswordResetEmail(email)
    .then(() => this.resetAsked = true )
    .catch((error) => console.log(error))
    this.emailToReset = email
    this.resetPasswordDone = true
    
    
  }

}
