import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { AngularFirestore } from '@angular/fire/firestore';
import { AuthenticationService } from 'src/app/services/authentication.service';
import { Router } from '@angular/router';
import { UsersService } from 'src/app/services/users.service';
import { ChatService } from 'src/app/services/chat.service';

@Component({
  selector: 'app-signin-user',
  templateUrl: './signin-user.component.html',
  styleUrls: ['./signin-user.component.css']
})
export class SigninUserComponent implements OnInit {

  signinForm: FormGroup
  //userId: any


  // FormBuilder est un constructeur de formulaires en methode REACTIVE
  constructor(
    private formBuilder: FormBuilder, 
    public afs: AngularFirestore, 
    private authenticationService: AuthenticationService,
    private usersService: UsersService,
    private chatService:ChatService,
    private router: Router
    ) { }
 
  ngOnInit() {

    this.signinForm = this.formBuilder.group({
      email: ['', [Validators.required, Validators.email]],
      password: ['',[Validators.required, Validators.minLength(6)]]

    });

    

  }



  signInUser(){

    const email = this.signinForm.get('email').value;
    const password = this.signinForm.get('password').value;
    
    // on appel le service qui retourne une promise
    this.authenticationService.signInUser(email, password)
    .catch(
      (error) => console.log('signInUser', error)
    )
    // () : valeur qui revient de la promesse signinUser mais comme je n'ai pas besoin des valeurs de retours () / en temps normal ce serait (data)
    .then(() =>  this.authenticationService.getCurrentUserDatasOneShot())
    .catch(
      (error) => console.log('getCurrentUserDatas', error)
    )
    .then(() => this.authenticationService.getProtegeUserDatas(this.authenticationService.user.userToProtect)) 
    .catch(
      (error) => {
        console.log('getProtegeUserDatas', error)
      }
    )
    .then(() => this.chatService.getProtegeChatId(this.authenticationService.user.email))
    .catch(
      (error) => {
        console.log('this.chatService.getProtegeChatId', error)
      }
    )
    .then(() => this.chatService.getAngelChatId(this.authenticationService.user.email))
    .catch(
      (error) => {
        console.log('this.chatService.getAngelChatId', error)
      }
    )
    .then(() => this.authenticationService.getAngelUserDatas(this.authenticationService.user.protectedByUser))
    .catch(
      (error) => {
        console.log('this.authenticationService.getAngelUserDatas', error)
      }
    )
    .then(() => this.router.navigate(['/user','dashboard']))
    .then(() => this.authenticationService.getCurrentUserDatas())  
    .catch(
      (error) => console.log('this.router.navigate', error)
    )
    
  }


}
